@@ -361,9 +361,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
               tau.common=tau.common,
               prediction=prediction,
               method.bias=method.bias,
-              title=title,
-              complab=complab,
-              outclab=outclab,
+              title=title, complab=complab, outclab=outclab,
               label.e=label.e,
               label.c=label.c,
               label.left=label.left,
